==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/src/base/WSDfont.cpp <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#include <WScom.h>
#include <WSDfont.h>
//饹
WSMFclassInit(WSDfont,WSDres);

//WSDfont::WSDfont(){
//}

//WSDfont::~WSDfont(){
//}

long WSDfont::setFontName(char* cname){
   return setSrc(cname);
}
char* WSDfont::getFontName(){
   return getSrc();
}
long WSDfont::setPrm(long /*kind*/,long  /*val*/){
  return WS_NO_ERR;
}
long WSDfont::getStringWidth(WSCstring* /*string*/){
  return 0;
}
long WSDfont::getStringHeight(WSCstring* /*string*/){
  return 0;
}
long WSDfont::getStringWidthUCS2(WSCushort* /*string*/){
  return 0;
}
long WSDfont::getStringHeightUCS2(WSCushort* /*string*/){
  return 0;
}
long WSDfont::getStringWidth(char* s,long en){
  WSCstring str;
  str.setString(s,en);
  return getStringWidth(&str);
}
long WSDfont::getStringHeight(char* s,long en){
  WSCstring str;
  str.setString(s,en);
  return getStringHeight(&str);
}

long WSDfont::getFontHeight(){
  return getStringHeight((WSCstring*)NULL);
}

==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/src/base/WSDfont.cpp <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#include <WScom.h>
#include <WSDfont.h>
//饹
WSMFclassInit(WSDfont,WSDres);

WSDfont::WSDfont(){
}

WSDfont::~WSDfont(){
}

long WSDfont::setFontName(char* cname){
   return setSrc(cname);
}
char* WSDfont::getFontName(){
   return getSrc();
}
long WSDfont::setPrm(long /*kind*/,long  /*val*/){
  return WS_NO_ERR;
}
long WSDfont::getStringWidth(WSCstring* /*string*/){
  return 0;
}
long WSDfont::getStringHeight(WSCstring* /*string*/){
  return 0;
}
long WSDfont::getStringWidthUCS2(WSCushort* /*string*/){
  return 0;
}
long WSDfont::getStringHeightUCS2(WSCushort* /*string*/){
  return 0;
}
long WSDfont::getStringWidth(char* s,long en){
  WSCstring str;
  str.setString(s,en);
  return getStringWidth(&str);
}
long WSDfont::getStringHeight(char* s,long en){
  WSCstring str;
  str.setString(s,en);
  return getStringHeight(&str);
}

long WSDfont::getFontHeight(){
  return getStringHeight((WSCstring*)NULL);
}
